# Pymaidol API 目录

## 模块

名称 | 描述
--- | ---
[AnnotationType 模块](AnnotationType/AnnotationType模块.md) | 提供了可在模板设计文件中`.pymd`使用的注释的枚举类型。

## 类

名称 | 描述
--- | ---
[Position 类](Position类.md) | 用于定位在原始模板字符串中的位置。
[TemplateBase 类](TemplateBase类.md) | Pymaidol 模板的后台类，是所有 Pymaidol 模板类的基类。
[TemplateRenderer 类](TemplateRenderer类.md) | 将模板字符串渲染为字符串的类。
